ValidacionImagenError enum
Values
- acercar → const ValidacionImagenError
-
const ValidacionImagenError('Acerque') - alejar → const ValidacionImagenError
-
const ValidacionImagenError('Aleje') - subir → const ValidacionImagenError
-
const ValidacionImagenError('Baja ') - bajar → const ValidacionImagenError
-
const ValidacionImagenError('Subi') - centrar → const ValidacionImagenError
-
const ValidacionImagenError('Centre') - noEncontrado → const ValidacionImagenError
-
const ValidacionImagenError('Acérque el documento') - ok → const ValidacionImagenError
-
const ValidacionImagenError('')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mensaje → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ValidacionImagenError> - A constant List of the values in this enum, in order of their declaration.